<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_CN">
<context>
    <name>notification::BubbleItem</name>
    <message>
        <source>just now</source>
        <translation>刚刚</translation>
    </message>
    <message>
        <source>1 new message</source>
        <translation>1条新消息</translation>
    </message>
</context>
<context>
    <name>notification::BubbleModel</name>
    <message>
        <source>%1 minutes ago</source>
        <translation>%1分钟前</translation>
    </message>
</context>
</TS>